@@ -1,12 +1,12 @@
 "iclust.diagram" <- 
-function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=.6, main="ICLUST diagram") {
+function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1, main="ICLUST diagram") {
 
  
 
 clusters <- ic$results  #the main table from ICLUST 
 num <- nrow(clusters)
 num.var <- num+1
-if(is.null(cex)) cex <- min(20/num.var,1)
+if(is.null(cex)) cex <- min(16/num.var,1)
 
 
     if (is.null(labels)) {
@@ -14,20 +14,21 @@ if(is.null(cex)) cex <- min(20/num.var,1)
     if (short) {var.labels <- paste("V",1:num.var,sep="")} 
     if(is.null(var.labels)) {var.labels <- paste("V",1:num.var,sep="")} 
 
-fixed <- fix.names(ic,var.labels)
-clusters <- fixed$ic$results
+#fixed <- fix.names(ic,var.labels)
+#clusters <- fixed$ic$results
+ max.len <- max(nchar((var.labels)))
 
-
-length.labels <- max(fixed$max.len * .12 * cex,.25*cex)
+length.labels <- max(max.len* .15 * cex,.25*cex)
 ##
 
 nc <- length(ic$size)
 nvar <- sum(ic$size)
 last <- dim(clusters)[1]
 max.size <- max(ic$size)
+
 limx <- c(-length.labels,nvar+2)
 limy <-  c(0,nvar+1)
-
+if(nvar < 12) e.size <- e.size * .7   #this is a kludge to make small problems look better
 
 
 if(is.null(min.size)) min.size <- .1 * nvar
@@ -77,10 +78,12 @@ for(clust in 1:nc) {
 
     
  "dia.cluster" <- 
- function(x, y = NULL, cluster, link=NULL, digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1), ...) {
-    text(x,y, rownames(cluster),pos=3,cex=cex)
-	text(x,y, substitute(list(alpha) == list(a),list(a=round(cluster[1,"alpha"],digits))),cex=cex) 
-	text(x,y, substitute(list(beta) == list(b), list(b=round(cluster[1,"beta"],digits))),cex=cex,pos=1) 
+ function(x, y = NULL, cluster, link=NULL, digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1),small=FALSE, ...) {
+   
+	if(!small) {
+	 text(x,y, rownames(cluster),pos=3,cex=cex)
+	 text(x,y, substitute(list(alpha) == list(a),list(a=round(cluster[1,"alpha"],digits))),cex=cex) 
+	text(x,y, substitute(list(beta) == list(b), list(b=round(cluster[1,"beta"],digits))),cex=cex,pos=1) } else { text(x,y, rownames(cluster),cex=cex) }
      vert <- cex*.3
      xs <- dia.ellipse1(x,y,xlim=xlim,ylim=ylim,e.size=e.size,...)
      left <- c(x-xs,y)
@@ -88,21 +91,9 @@ for(clust in 1:nc) {
      top <- c(x,y+xs)
      bottom <- c(x,y-xs)
      center <- c(x,y)
-    dia.cluster <- list(left=left,right=right,top=top,bottom=bottom,center=center,link=link)
+    dia.cluster <- list(left=left,right=right,top=top,bottom=bottom,center=center,link=link,radius=xs)
      }
   
- "dia.cluster2" <- 
- function(x, y = NULL, cluster, link=NULL, digits=2,cex = cex,e.size=.5,xlim=c(0,1),ylim=c(0,1), ...) {
-    text(x,y, rownames(cluster),cex=cex)
-	 vert <- cex*.3
-     xs <- dia.ellipse1(x,y,xlim=xlim,ylim=ylim,e.size=e.size,...)
-     left <- c(x-xs,y)
-     right <- c(x+xs,y)
-     top <- c(x,y+xs)
-     bottom <- c(x,y-xs)
-     center <- c(x,y)
-    dia.cluster2 <- list(left=left,right=right,top=top,bottom=bottom,center=center,link=link)
-     }
      
   #down is a recursive function that draws the complete cluster structure
   
@@ -113,22 +104,22 @@ for(clust in 1:nc) {
            size <- clusters[head,"size"]
 		   cluster <- clusters[head,]
 		   if(is.null(old.loc)) {link <- NULL} else {link <- old.head}   #remember the cluster that spawned this cluster
-           if(size > min.size) {c.loc <- dia.cluster(head+shift,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size) } else {c.loc <- dia.cluster2(head+2,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size*.6)}
+           if(size > min.size) {c.loc <- dia.cluster(head+shift,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size) } else {c.loc <- dia.cluster(head+2,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size*.6,small=TRUE)}
 
            if(!is.null(old.loc)) { 
            						if(old.loc$top[2] < c.loc$top[2]) {labels <- round(clusters[c.loc$link,"r1"],digits) } else { labels <- round(clusters[c.loc$link,"r2"],digits)}
         						if(old.loc$left[1] < c.loc$right[1]) {
         											if(old.loc$left[2] < c.loc$right[2]) { 
-                                          				dia.arrow(old.loc$center,c.loc$center,labels=labels,cex=cex,radius1=e.size,radius2=e.size)} else {
-                                          dia.arrow(old.loc$center,c.loc$center,labels=labels,cex=cex,radius1=e.size,radius2=e.size)}} else {
-          					 dia.arrow(old.loc$center,c.loc$center,labels=labels,cex=cex,radius1=e.size,radius2=e.size)}}
+                                          				dia.arrow(old.loc,c.loc,labels=labels,cex=cex)} else {
+                                          dia.arrow(old.loc,c.loc,labels=labels,cex=cex)}} else {
+          					 dia.arrow(old.loc,c.loc,labels=labels,cex=cex)}}
                 size1 <- clusters[head,"size1"]
                 size2 <- clusters[head,"size2"]
                                                                 
                if(size1==1) {
                 v.loc <-  dia.rect(0,y+.5,clusters[head,1],xlim=limx,ylim=limy,cex=cex,...)
 
-                dia.arrow(c.loc$center,v.loc$right,round(cluster["r1"],digits),cex=cex,radius1=e.size)
+                dia.arrow(c.loc,v.loc$right,round(cluster["r1"],digits),cex=cex)
                   } else {
                     
                		head1 <- which(rownames(clusters)== clusters[head,1]) 
@@ -142,7 +133,7 @@ for(clust in 1:nc) {
 
               			v.loc <- dia.rect(0,y-.5,clusters[head,2],xlim=limx,ylim=limy,cex=cex,...)
 
-              			dia.arrow(c.loc$center,v.loc$right,labels = round(clusters[head,"r2"],digits),cex=cex,radius1=e.size)
+              			dia.arrow(c.loc,v.loc$right,labels = round(clusters[head,"r2"],digits),cex=cex)
 
               			 } else {
               			 old.head <- head
