@@ -1,8 +1,18 @@
 "error.crosses" <-
-function (x,y,labels=NULL,pos=NULL,arrow.len=.2,...)  # x  and y are data frame with 
-    {z <- dim(x)[1]
+function (x,y,labels=NULL,pos=NULL,arrow.len=.2,...)  # x  and y are data frame or descriptive stats
+    {if(is.null(x$mean)) {x <- describe(x)
+     xmin <- min(x$min)
+     xmax <- max(x$max)}
+     if(is.null(y$mean)) {y <- describe(y)
+      ymin <- min(y$min)
+     ymax <- max(y$max)
+     plot(x$mean,y$mean,xlim=c(xmin,xmax),ylim=c(ymin,ymax),...)}
+     
+    
+    z <- dim(x)[1]
      if (length(pos)==0) {locate <- rep(1,z)} else {locate <- pos}
      if (length(labels)==0) lab <- rep("",z) else lab <-labels
+     
         for (i in 1:z)  
     	{xcen <- x$mean[i]
     	 ycen <- y$mean[i]
@@ -14,3 +24,4 @@ function (x,y,labels=NULL,pos=NULL,arrow.len=.2,...)  # x  and y are data frame
     	}	
    }
 
+
