@@ -76,13 +76,27 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
    
      class(loadings) <- "loadings"
      
-    result <- factor.stats(r,loadings,Phi,n.obs)
+    result$n.obs <- n.obs
+    stats <- factor.stats(r,loadings,Phi,n.obs)
     class(result) <- c("psych", "principal") 
     result$fn <- "principal"
     result$loadings <- loadings
     result$Phi <- Phi
     result$Call <- cl
     result$communality <- communalities
+    result$stats <- stats
+    result$objective <- stats$objective
+    result$residual <- stats$residual
+    result$fit <-  stats$fit
+    result$fit.off <-  stats$fit.off
+    result$factors <-  stats$factors
+    result$dof <-  stats$dof
+    result$criteria <-  stats$criteria
+    result$STATISTIC <-  stats$STATISTIC
+    result$PVAL <-  stats$PVAL
+    result$weights <-  stats$weights
+    result$r.scores <-  stats$r.scores
+    
     if(scores) {result$scores <- factor.scores(scale(x.matrix),loadings) }
     return(result)
    }
@@ -94,4 +108,6 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
   #modified December 30 to let n.obs ==NA rather than NULL to be compatible with factanal
   #modified Jan 14, 2009 to change phi to Phi  to avoid confusion
   #modified Jan 19, 2009 to allow for promax rotations
-  #modified May 15, 2009 to allow for singular matrices
\ No newline at end of file
+  #modified May 15, 2009 to allow for singular matrices
+  #correct August 25, 2009 to return result$values
+  #modified August 25 to return result$stats
\ No newline at end of file
