@@ -79,7 +79,8 @@ p.iris <- principal(IRIS,5,scores=TRUE)
 cluster.plot(factor.pa(sim.circ(nvar=24),nf=2),title="two circumplex factors")
  pairs.panels(cong) 
  #this section tests various functions that use Rgraphviz (if it is installed) 
- if(require(Rgraphviz)) { fa.graph(fa(item.sim(16),2) ,title="Principal factor of a simple structure") 
+#  if(require(Rgraphviz))       
+ if(FALSE) { fa.graph(fa(item.sim(16),2) ,title="Principal factor of a simple structure") 
   	ic.out <- ICLUST(s4,title="ICLUST of 24 Mental abilities")
   	jen <-  omega(sim.hierarchical(),title="Omega with Schmid Leihman")
   	omega.graph(jen,sl=FALSE,title="Omega with hierarchical factors")
